@@ -637,14 +637,10 @@ class BOJenkinsRunDatabaserCommand(
             f'{self._bojenkins_config["jenkins"]["databaser_job_name"].value}'
         )
 
-        job_info = self._jenkins_server.get_job_info(
-            name=job_name,
-        )
+        job_info = self._jenkins_server.get_job_info(name=job_name)
+        last_number = job_info['lastBuild']['number']
 
-        if (
-            not job_info['inQueue']
-            and job_info['lastBuild']['number'] == job_info['lastCompletedBuild']['number']
-        ):
+        if not (job_info['inQueue'] or self._jenkins_server.get_build_info(job_name, last_number)['building']):
             self._jira_client = JiraAPIClient(
                 url=self._bojira_config['jira']['url'].value,
                 username=self._bojira_config['jira']['username'].value,
