@@ -241,6 +241,7 @@ class ProjectPluginEnum(Enum):
     URM_KRISTA = 'urm_krista'
     PERIOD_CLOSING_EXT = 'period_closing_ext'
     IMPORT_PP_WEB = 'import_pp_web'
+    WEB_EXECUTION = 'web_execution'
 
     # Плигины ЗиК
     SALARY = 'salary'
@@ -481,6 +482,7 @@ class ProjectPluginEnum(Enum):
                     cls.UDMURTIA_UFK,
                     cls.PERIOD_CLOSING_EXT,
                     cls.IMPORT_PP_WEB,
+                    cls.WEB_EXECUTION,
                 )
             )
 
@@ -689,6 +691,9 @@ class ProjectPluginEnum(Enum):
             cls.UDMURTIA_UFK: (
                 cls.ACCOUNTING,
             ),
+            cls.WEB_EXECUTION: (
+                cls.ACCOUNTING,
+            ),
         }
 
     @classmethod
